@@ -189,6 +189,7 @@ fn highlight_diff<W: io::Write + Send + 'static>(
     let mut line: Vec<u8> = Vec::new();
     let mut buf: [u8; 16384] = [0; 16384];
     let mut line_number = 1usize;
+    let mut stream_started_with_esc: Option<bool> = None;
     loop {
         let result = input.read(&mut buf);
         if result.is_err() {
@@ -196,11 +197,17 @@ fn highlight_diff<W: io::Write + Send + 'static>(
         }
 
         let read_count = result.unwrap();
+        if read_count > 0 && stream_started_with_esc.is_none() {
+            stream_started_with_esc = Some(buf[0] == b'\x1b');
+        }
+
         if read_count == 0 {
             // End of stream
             if !line.is_empty() {
                 // Stuff found on the last line without a trailing newline
-                if let Err(message) = line_collector.consume_line(&line) {
+                if let Err(message) =
+                    line_collector.consume_line(&line, stream_started_with_esc.unwrap_or(false))
+                {
                     error!("{}", format_error(message, line_number, &line));
                 }
             }
@@ -220,7 +227,9 @@ fn highlight_diff<W: io::Write + Send + 'static>(
             }
 
             // Line finished, consume it!
-            if let Err(message) = line_collector.consume_line(&line) {
+            if let Err(message) =
+                line_collector.consume_line(&line, stream_started_with_esc.unwrap_or(false))
+            {
                 error!("{}", format_error(message, line_number, &line));
             }
             line.clear();
@@ -585,6 +594,7 @@ mod tests {
     use super::*;
     use std::{collections::HashSet, fs, path::PathBuf};
 
+    use base64::{engine::general_purpose, Engine};
     #[cfg(test)]
     use pretty_assertions::assert_eq;
 
@@ -680,8 +690,8 @@ mod tests {
 
         // Iterate over all the example output files
         let mut failing_example: Option<String> = None;
-        let mut failing_example_expected = vec![];
-        let mut failing_example_actual = vec![];
+        let mut failing_example_expected = String::new();
+        let mut failing_example_actual = String::new();
         let mut failure_count = 0;
         for expected_output_file in riff_output_files {
             let without_riff_output_extension =
@@ -698,8 +708,8 @@ mod tests {
             if !riff_input_file.is_file() {
                 if failing_example.is_none() {
                     failing_example = Some(expected_output_file.to_str().unwrap().to_string());
-                    failing_example_expected = vec![];
-                    failing_example_actual = vec![];
+                    failing_example_expected = String::new();
+                    failing_example_actual = String::new();
                 }
 
                 println!(
@@ -731,19 +741,8 @@ mod tests {
 
                 failing_example = Some(riff_input_file.to_str().unwrap().to_string());
 
-                let actual_lines: Vec<String> = failure
-                    .actual_result
-                    .split('\n')
-                    .map(str::to_string)
-                    .collect();
-                let expected_lines: Vec<String> = failure
-                    .expected_result
-                    .split('\n')
-                    .map(str::to_string)
-                    .collect();
-
-                failing_example_expected = expected_lines;
-                failing_example_actual = actual_lines;
+                failing_example_actual = failure.actual_result;
+                failing_example_expected = failure.expected_result;
             }
         }
 
@@ -753,6 +752,21 @@ mod tests {
             println!();
             println!("Example: {}", failing_example);
             println!();
+            println!("Actual {} highlighting:", failing_example);
+            for line in failing_example_actual.lines() {
+                println!("  {}", line);
+            }
+            println!();
+            println!("Expected {} highlighting:", failing_example);
+            for line in failing_example_expected.lines() {
+                println!("  {}", line);
+            }
+            println!();
+            println!(
+                "Actual as base64: {}",
+                general_purpose::STANDARD.encode(&failing_example_actual)
+            );
+            println!();
             println!("==> Run \"./testdata-examples.sh\" to visualize changes / failures");
             println!();
 
@@ -801,7 +815,7 @@ mod tests {
         // Load the corresponding .riff-output file into a string
         let expected_result = fs::read_to_string(expected_output_file).unwrap();
 
-        if actual_result != expected_result {
+        if !actual_result.lines().eq(expected_result.lines()) {
             return Some(ExampleFailure {
                 diagnostics: "Output mismatches".to_string(),
                 actual_result,
